==> korweblog-1.5.8.tar.gz: korweblog-1.5.8/config.php <==
<?
include("include/common.inc.php");

settype($what, "string");
if ($what=="save_cookie") {
	if (!$cu['climit']) $cu['climit'] = $CONF['PAGE_REPLY_LIMIT'];
   if ($cu['alloff'] || !count($blocks)) { unset($blocks); $blocks[] = "none"; }
   if (is_array($blocks)) $blocks = array_keys($blocks);
   if ($login && $user['uid']) {
      SqlQuery("UPDATE T_Users SET config = '". serialize($cu) ."',
                                    blocks = '". serialize($blocks) ."',
                                    block_key = '$blockconfig'
                                    WHERE uid = $user[uid]");
   } else {
      KWL_DoCookie("config",serialize($cu),15552000);
      KWL_DoCookie("$blockconfig",serialize($blocks),15552000);
   }
   $msg = urlencode(_SAVED);
   KWL_Redirect("config.php?msg=$msg");
   exit;
}
$head = _CONFIG;
include("include/header.inc.php");

if ($login) KWL_UserNavig();

/* just for error_reporting(E_ALL) */
$carray = array('alloff','iconoff','nocom','noscore');
foreach ($carray as $k) {
   if (!isset($user['config'][$k])) $user['config'][$k] = 0;
}

$VAR['Heading'] = KWL_PrepareHtml($CONF['SiteName']) . " " . _CONFIG;
$out = new KWL_Html;
$VAR['Content'] = $out->form_start("config.php","config").
                $out->table_start("100%",'',0,0,3).
"<TR>
   <TD>". $out->check_box("cu[alloff]",$user['config']['alloff']) . _DEACTIVE ."<BR>".
          $out->check_box("cu[iconoff]",$user['config']['iconoff']) . _ICONOFF ."<BR>".
          $out->check_box("cu[nocom]",$user['config']['nocom']) . _NOCOMMENT;

if (!empty($CONF['SCORING'])) {
   $VAR['Content'] .= "<BR>". $out->check_box("cu[noscore]",$user['config']['noscore']) . _NOSCORE;
}

$VAR['Content'] .= "</TD></TR>". $out->table_end();
KWL_DrawMain($VAR);
settype($cmode, "string");
$comment_sort = isset($comment_sort) ? strtolower($comment_sort) : "desc";
$VAR['Heading'] = _COMMENT_PREF;
$VAR['Content'] = $out->table_start("100%",'',0,0,3).
"<TR>
   <TD>". _CMODE1 . " : ". 
   $out->select("cu[nc]", array( "nest"     => "Nested",
                                 "thread"   => "Threaded",
                                 "flat"     => "Flat",
                                 "unthread" => "Unthreaded" ),
                $cmode) .
"<BR>". _CMODE2 . " : ".
   $out->select("cu[cs]", array( "desc" => _SORT_NEW,
                                 "asc"  => _SORT_OLD ),
                $comment_sort);

if ($CONF['PAGE_REPLY']) {
   $VAR['Content'] .= "<BR>" . _REPLY_PAGES_DESC . ": " .
	                 "<select name=\"cu[climit]\">\n";
	for($i=5;$i<$CONF['PAGE_REPLY_LIMIT'];$i+=5) {
      $VAR['Content'] .= "<option value=\"$i\"> $i \n";
   }
   $VAR['Content'] .= "<option value=\"". $CONF['PAGE_REPLY_LIMIT'] ."\" selected> ". $CONF['PAGE_REPLY_LIMIT'] ."\n";
   for($i=$CONF['PAGE_REPLY_LIMIT']+5; $i < 55; $i=$i + 5) {	
      $VAR['Content'] .= "<option value=\"$i\"> $i \n";
   }
   $VAR['Content'] .= "</select>";
}
if (!empty($CONF['SCORING'])) {
   $VAR['Content'] .= "<BR>". _SCORE ." : ".
                    $out->select("cu[sc]", array( -1 => -1,
                                                   0 => 0,
                                                   1 => 1), 
                                 $score) ." (". _DESC_SCORE .")";
} else $VAR['Content'] .= $out->input_form("hidden","sc",-1);

$VAR['Content'] .= "</TD></TR>". $out->table_end();
KWL_DrawMain($VAR);

$VAR['Heading'] = _BLOCKS;
$VAR['Content'] = $out->table_start("100%",'',0,0,3).
"<TR>
	<TD VALIGN=TOP VALIGN=TOP WIDTH=\"50%\">";
$blocks_result = SqlQuery("SELECT * FROM T_Blocks WHERE Display = 'r' OR Display = 'l' ORDER BY Display, OrderID");
$blocks_nums = mysql_num_rows($blocks_result);

if ($blocks_nums) {
   $divide = floor($blocks_nums / 2);
   $i = 1;
   while ($A = mysql_fetch_array($blocks_result)) {
      if (count($user_blocks)) {
         $ass = (in_array($A['Rid'],$user_blocks)) ? 1 : 0;
      } else $ass = 1;
      if ($A['Type'] == 3) $title = KWL_PrepareHtml(KWL_SblockTitle($A['URL']));
      else $title = KWL_PrepareHtml($A['Heading']);
      $VAR['Content'] .= $out->check_box("blocks[$A[Rid]]",$ass) . $title ."<BR>\n";
      if ($divide == $i) {
         $VAR['Content'] .= "</TD><TD VALIGN=TOP VALIGN=TOP WIDTH=\"50%\">";
      }
      $i++;
   }
}

$VAR['Content'] .= "&nbsp;</TD>
<TR>
   <TD ALIGN=CENTER COLSPAN=2>".
   $out->input_form("hidden","what","save_cookie") .
   $out->input_form("hidden","blockconfig",$blockconfig) .
   $out->input_form("submit",'',_SAVE_CHANGE) ."</TD>
</TR>". $out->table_end();
KWL_DrawMain($VAR);
echo $out->form_end();

include("include/footer.inc.php");
?>

==> korweblog-1.5.9.tar.gz: korweblog-1.5.9/config.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

include("include/common.inc.php");

settype($what, "string");
if ($what=="save_cookie") {
	if (!$cu['climit']) $cu['climit'] = $CONF['PAGE_REPLY_LIMIT'];
   if ($cu['alloff'] || !count($blocks)) { unset($blocks); $blocks[] = "none"; }
   if (is_array($blocks)) $blocks = array_keys($blocks);
   if ($login && $user['uid']) {
      SqlQuery("UPDATE T_Users SET config = '". serialize($cu) ."',
                                    blocks = '". serialize($blocks) ."',
                                    block_key = '$blockconfig'
                                    WHERE uid = $user[uid]");
   } else {
      KWL_DoCookie("config",serialize($cu),15552000);
      KWL_DoCookie("$blockconfig",serialize($blocks),15552000);
   }
   $msg = urlencode(_SAVED);
   KWL_Redirect("config.php?msg=$msg");
   exit;
}
$head = _CONFIG;
include("include/header.inc.php");

if ($login) KWL_UserNavig();

/* just for error_reporting(E_ALL) */
$carray = array('alloff','iconoff','nocom','noscore');
foreach ($carray as $k) {
   if (!isset($user['config'][$k])) $user['config'][$k] = 0;
}

$VAR['Heading'] = KWL_PrepareHtml($CONF['SiteName']) . " " . _CONFIG;
$out = new KWL_Html;
$VAR['Content'] = $out->form_start("config.php","config").
                $out->table_start("100%",'',0,0,3).
"<tr>
   <td>". $out->check_box("cu[alloff]",$user['config']['alloff']) . _DEACTIVE ."<br />".
          $out->check_box("cu[iconoff]",$user['config']['iconoff']) . _ICONOFF ."<br />".
          $out->check_box("cu[nocom]",$user['config']['nocom']) . _NOCOMMENT;

if (!empty($CONF['SCORING'])) {
   $VAR['Content'] .= "<br />". $out->check_box("cu[noscore]",$user['config']['noscore']) . _NOSCORE;
}

$VAR['Content'] .= "</td></tr>". $out->table_end();
KWL_DrawMain($VAR);
settype($cmode, "string");
$comment_sort = isset($comment_sort) ? strtolower($comment_sort) : "desc";
$VAR['Heading'] = _COMMENT_PREF;
$VAR['Content'] = $out->table_start("100%",'',0,0,3).
"<tr>
   <td>". _CMODE1 . " : ". 
   $out->select("cu[nc]", array( "nest"     => "Nested",
                                 "thread"   => "Threaded",
                                 "flat"     => "Flat",
                                 "unthread" => "Unthreaded" ),
                $cmode) .
"<br />". _CMODE2 . " : ".
   $out->select("cu[cs]", array( "desc" => _SORT_NEW,
                                 "asc"  => _SORT_OLD ),
                $comment_sort);

if ($CONF['PAGE_REPLY']) {
   $VAR['Content'] .= "<br />" . _REPLY_PAGES_DESC . ": " .
	                 "<select name=\"cu[climit]\">\n";
	for($i=5;$i<$CONF['PAGE_REPLY_LIMIT'];$i+=5) {
      $VAR['Content'] .= "<option value=\"$i\"> $i \n";
   }
   $VAR['Content'] .= "<option value=\"". $CONF['PAGE_REPLY_LIMIT'] ."\" selected> ". $CONF['PAGE_REPLY_LIMIT'] ."\n";
   for($i=$CONF['PAGE_REPLY_LIMIT']+5; $i < 55; $i=$i + 5) {	
      $VAR['Content'] .= "<option value=\"$i\"> $i \n";
   }
   $VAR['Content'] .= "</select>";
}
if (!empty($CONF['SCORING'])) {
   $VAR['Content'] .= "<br />". _SCORE ." : ".
                    $out->select("cu[sc]", array( -1 => -1,
                                                   0 => 0,
                                                   1 => 1), 
                                 $score) ." (". _DESC_SCORE .")";
} else $VAR['Content'] .= $out->input_form("hidden","sc",-1);

$VAR['Content'] .= "</td></tr>". $out->table_end();
KWL_DrawMain($VAR);

$VAR['Heading'] = _BLOCKS;
$VAR['Content'] = $out->table_start("100%",'',0,0,3).
"<tr>
	<td valign=\"top\" valign=\"top\" width=\"50%\">";
$blocks_result = SqlQuery("SELECT * FROM T_Blocks WHERE Display = 'r' OR Display = 'l' ORDER BY Display, OrderID");
$blocks_nums = mysql_num_rows($blocks_result);

if ($blocks_nums) {
   $divide = floor($blocks_nums / 2);
   $i = 1;
   while ($A = mysql_fetch_array($blocks_result)) {
      if (count($user_blocks)) {
         $ass = (in_array($A['Rid'],$user_blocks)) ? 1 : 0;
      } else $ass = 1;
      if ($A['Type'] == 3) $title = KWL_PrepareHtml(KWL_SblockTitle($A['URL']));
      else $title = KWL_PrepareHtml($A['Heading']);
      $VAR['Content'] .= $out->check_box("blocks[$A[Rid]]",$ass) . $title ."<br />\n";
      if ($divide == $i) {
         $VAR['Content'] .= "</td><td VALIGN=TOP VALIGN=TOP WIDTH=\"50%\">";
      }
      $i++;
   }
}

$VAR['Content'] .= "&nbsp;</td>
<tr>
   <td align=\"center\" colspan=\"2\">".
   $out->input_form("hidden","what","save_cookie") .
   $out->input_form("hidden","blockconfig",$blockconfig) .
   $out->input_form("submit",'',_SAVE_CHANGE) ."</td>
</tr>". $out->table_end();
KWL_DrawMain($VAR);
echo $out->form_end();

include("include/footer.inc.php");
?>
